# 2b2t.py
 This package handles all things 2b2t!


## Installation

You can install the package with pip.

```
pip install 2b2t
```


or

```

pip3 install 2b2t
```


Or you can install with GitHub

1. Clone the repo
2. Run setup.py
3. Install Python3 if you don't already have it
4. Install requests and colorama if you don't already have it
```
git clone https://github.com/BGP0/2b2t.py.git
python3 setup.py build install
pip3 install requests
pip3 install colorama
```
## Usage

[Docs](https://github.com/BGP0/2b2t.py/wiki)

## Credits

Orginal Software made by BGP 


Thanks to SkilzMastr for turning the checker into a package!
